==> openshift-model-5.8.1-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicyReviewSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodSecurityPolicyReviewSpecBuilder extends io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluentImpl<io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec,io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecBuilder>{
  public PodSecurityPolicyReviewSpecBuilder() {
    this(false);
  }
  public PodSecurityPolicyReviewSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new PodSecurityPolicyReviewSpec(), validationEnabled);
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodSecurityPolicyReviewSpec(), validationEnabled);
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec instance) {
    this(fluent, instance, false);
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withServiceAccountNames(instance.getServiceAccountNames()); 
    fluent.withTemplate(instance.getTemplate()); 
    this.validationEnabled = validationEnabled; 
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec instance) {
    this(instance,false);
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withServiceAccountNames(instance.getServiceAccountNames()); 
    this.withTemplate(instance.getTemplate()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec build() {
    PodSecurityPolicyReviewSpec buildable = new PodSecurityPolicyReviewSpec(fluent.getServiceAccountNames(),fluent.getTemplate());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodSecurityPolicyReviewSpecBuilder that = (PodSecurityPolicyReviewSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicyReviewSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodSecurityPolicyReviewSpecBuilder extends io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluentImpl<io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec,io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecBuilder>{
  public PodSecurityPolicyReviewSpecBuilder() {
    this(false);
  }
  public PodSecurityPolicyReviewSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new PodSecurityPolicyReviewSpec(), validationEnabled);
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodSecurityPolicyReviewSpec(), validationEnabled);
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec instance) {
    this(fluent, instance, false);
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withServiceAccountNames(instance.getServiceAccountNames()); 
    fluent.withTemplate(instance.getTemplate()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec instance) {
    this(instance,false);
  }
  public PodSecurityPolicyReviewSpecBuilder(io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withServiceAccountNames(instance.getServiceAccountNames()); 
    this.withTemplate(instance.getTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.PodSecurityPolicyReviewSpec build() {
    PodSecurityPolicyReviewSpec buildable = new PodSecurityPolicyReviewSpec(fluent.getServiceAccountNames(),fluent.getTemplate());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodSecurityPolicyReviewSpecBuilder that = (PodSecurityPolicyReviewSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
